PyXMake Developer Guide: PyXMake.Build.__install__ Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Variables
PyXMake.Build.__install__ Namespace Reference

Fetch 3rd party dependencies for PyXMake from DLR's resource server. More...

## Variables
string | package_name = "Perl"
| download_path = os.path.join(os.path.expanduser('~/Downloads'), __pyx_zip_file)
| pathlist = list([])

## Detailed Description

Fetch 3rd party dependencies for PyXMake from DLR's resource server.

    Fetch 3rd party dependencies for PyXMake from DLR's resource server.

    @note: PyXMake 3rd party dependency installer
    Created on 04.08.2020

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

Author
  Marc Garbade

Date
  04.08.2020

Notes/Changes
  - Added documentation // mg 04.08.2020